#!/bin/sh

FIRMWARE=/var/www/localhost/htdocs/sonoff-basic.bin

date

ID=$(avahi-browse -t _ewelink._tcp -v --resolve 2&>/dev/null | grep "^\s*txt" | sed 's/.*\"id\=\(.*\)\"\ .*/\1/')

if [ "$ID" = "" ] ; then
  echo "Sonoff Diy not found!"
  exit 1
fi

IP=$(avahi-browse -t _ewelink._tcp -v --resolve 2&>/dev/null | grep "^\s*address" | sed 's/.*\[\(.*\)\].*/\1/')

if [ "$IP" = "" ] ; then
  echo "Cannot get IP address!"
  exit 1
fi

echo "Found Sonoff Diy!"
echo "  ID: $ID"
echo "  IP ADDRESS: $IP"

echo
echo "Testing INFO connection:"
CONN=$(curl -s http://$IP:8081/zeroconf/info -XPOST --data "{\"deviceid\":\"$ID\",\"data\":{}}")
echo "Result: $CONN"

sleep 3

echo
echo "Unlocking OTA:"
OTAUN=$(curl -s http://$IP:8081/zeroconf/ota_unlock -XPOST --data "{\"deviceid\":\"$ID\",\"data\":{}}")
echo "Result: $OTAUN"

sleep 3

echo
echo "Calculating SHA 256 sum of firmware"
SUM=$(sha256sum $FIRMWARE | awk '{print $1;}')

echo "$FIRMWARE: $SUM"

echo
echo "Requesting flash (brushing machine :) )"
FLASH=$(curl -s http://$IP:8081/zeroconf/ota_flash -XPOST --data "{\"deviceid\":\"$ID\",\"data\":{\"downloadUrl\":\"http://10.101.111.1/sonoff-basic.bin\",\"sha256sum\":\"$SUM\"}}")

echo "Result: $FLASH"

